@@ -3,20 +3,20 @@
 from peext.core import RegulatableMESModel
 
 
-MDOT_KG_PER_S = 'mdot_kg_per_s'
-ACTIVE_POWER = 'p_mw'
-REACTIVE_POWER = 'q_mvar'
-VOLTAGE = 'vm_pu'
-VOLTAGE_ANGLE = 'va_degree'
-SCALING = 'scaling'
-CONTROLLER_OBJ_KEY = 'object'
-NAME_KEY = 'name'
-HEAT_ENERGY = 'heat_energy'
-QEXT_W = 'qext_w'
+MDOT_KG_PER_S = "mdot_kg_per_s"
+ACTIVE_POWER = "p_mw"
+REACTIVE_POWER = "q_mvar"
+VOLTAGE = "vm_pu"
+VOLTAGE_ANGLE = "va_degree"
+SCALING = "scaling"
+CONTROLLER_OBJ_KEY = "object"
+NAME_KEY = "name"
+HEAT_ENERGY = "heat_energy"
+QEXT_W = "qext_w"
+
 
 class RegulatableController(RegulatableMESModel):
-    """Base class for regulatable controller Nodes.
-    """
+    """Base class for regulatable controller Nodes."""
 
     def component_type(self):
         return "controller"
@@ -55,8 +55,7 @@ class RegulatableController(RegulatableMESModel):
 
 
 class G2PNode(RegulatableController):
-    """Node representing g2p system. Contains wrapper functions for accessing the relevant information and control variables.
-    """
+    """Node representing g2p system. Contains wrapper functions for accessing the relevant information and control variables."""
 
     def power_output(self) -> float:
         """
@@ -74,18 +73,25 @@ class G2PNode(RegulatableController):
 
     def active_power_capability(self):
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].power_cap
-        
+
     def mdot_kg_per_s_capability(self):
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].gas_cap
-        
+
     def values_as_dict(self):
-        return {ACTIVE_POWER: self.power_output(), MDOT_KG_PER_S: self.gas_consume(), 
-                'sink': self.network.controller[CONTROLLER_OBJ_KEY][self.id].get_gas_consume(self.network), 
-                'gen': self.network.controller[CONTROLLER_OBJ_KEY][self.id].get_power_production(self.network)}
+        return {
+            ACTIVE_POWER: self.power_output(),
+            MDOT_KG_PER_S: self.gas_consume(),
+            "sink": self.network.controller[CONTROLLER_OBJ_KEY][
+                self.id
+            ].get_gas_consume(self.network),
+            "gen": self.network.controller[CONTROLLER_OBJ_KEY][
+                self.id
+            ].get_power_production(self.network),
+        }
+
 
 class P2GNode(RegulatableController):
-    """Node representing p2g system. Contains wrapper functions for accessing the relevant information and control variables.
-    """
+    """Node representing p2g system. Contains wrapper functions for accessing the relevant information and control variables."""
 
     def mdot_kg_per_s(self) -> float:
         """
@@ -111,34 +117,46 @@ class P2GNode(RegulatableController):
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].gas_cap
 
     def values_as_dict(self):
-        return {MDOT_KG_PER_S: self.mdot_kg_per_s(), ACTIVE_POWER: self.power_load(), 
-                'source': self.network.controller[CONTROLLER_OBJ_KEY][self.id].get_source_production(self.network), 
-                'load': self.network.controller[CONTROLLER_OBJ_KEY][self.id].get_power_load(self.network)}
+        return {
+            MDOT_KG_PER_S: self.mdot_kg_per_s(),
+            ACTIVE_POWER: self.power_load(),
+            "source": self.network.controller[CONTROLLER_OBJ_KEY][
+                self.id
+            ].get_source_production(self.network),
+            "load": self.network.controller[CONTROLLER_OBJ_KEY][self.id].get_power_load(
+                self.network
+            ),
+        }
+
 
 class CHPNode(RegulatableController):
-    """Node representing chp with gas turbine system. Contains wrapper functions for accessing the relevant information and control variables.
-    """
+    """Node representing chp with gas turbine system. Contains wrapper functions for accessing the relevant information and control variables."""
 
     def heat_output(self) -> float:
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].heat_energy
 
+    def qext_w(self) -> float:
+        return self.network.controller[CONTROLLER_OBJ_KEY][self.id].heat_energy
+
     def power_output(self) -> float:
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].power_gen
 
     def active_power(self) -> float:
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].power_gen
-    
+
     def storage_load(self):
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].storage_load
 
     def mdot_kg_per_s(self) -> float:
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].gas_cons
-    
+
     def heat_regulation_factor(self):
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].heat_regulation
 
     def regulate_heat(self, regulation):
-        self.network.controller[CONTROLLER_OBJ_KEY][self.id].heat_regulation = regulation
+        self.network.controller[CONTROLLER_OBJ_KEY][
+            self.id
+        ].heat_regulation = regulation
 
     def active_power_capability(self):
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].power_cap
@@ -155,19 +173,22 @@ class CHPNode(RegulatableController):
     def state_as_dict(self):
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].state_as_dict()
 
+
 class P2HNode(RegulatableController):
-    """Node representing P2H. 
-    """
+    """Node representing P2H."""
 
     def heat_output(self) -> float:
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].heat_energy
 
+    def qext_w(self) -> float:
+        return self.network.controller[CONTROLLER_OBJ_KEY][self.id].heat_energy
+
     def power_load(self) -> float:
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].power_load
 
     def active_power(self) -> float:
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].power_load
-    
+
     def active_power_capability(self):
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].power_cap
 
@@ -182,8 +203,7 @@ class P2HNode(RegulatableController):
 
 
 class PowerLoadNode(RegulatableMESModel):
-    """Node representing power load.
-    """
+    """Node representing power load."""
 
     def active_power(self) -> float:
         """
@@ -198,7 +218,7 @@ class PowerLoadNode(RegulatableMESModel):
         :rtype: float
         """
         return self._network.res_load[REACTIVE_POWER][self._id]
-    
+
     def regulate(self, new_scaling):
         """Set the regulation factor.
 
@@ -229,16 +249,41 @@ class PowerLoadNode(RegulatableMESModel):
         :rtype: float
         """
         return self._network.load[ACTIVE_POWER][self._id]
-    
+
     def component_type(self):
         return "load"
 
     def values_as_dict(self):
         return self._network.res_load.iloc[self._id]
 
+
+class SwitchNode(RegulatableMESModel):
+    def regulate(self, _):
+        pass
+
+    def regulation_factor(self) -> float:
+        return 1
+
+    def name(self):
+        """Return name of the ext grid
+
+        :return: the name
+        :rtype: str
+        """
+        return self._network.switch[NAME_KEY][self._id]
+
+    def active_power_capability(self):
+        return 0
+
+    def component_type(self):
+        return "switch"
+
+    def values_as_dict(self):
+        return self._network.res_switch.iloc[self._id]
+
+
 class SGeneratorNode(RegulatableMESModel):
-    """Node representing a static generator
-    """
+    """Node representing a static generator"""
 
     def active_power(self):
         """
@@ -284,16 +329,16 @@ class SGeneratorNode(RegulatableMESModel):
         :rtype: float
         """
         return self._network.sgen[ACTIVE_POWER][self._id]
-    
+
     def component_type(self):
         return "sgen"
 
     def values_as_dict(self):
         return self._network.res_sgen.iloc[self._id]
 
+
 class GeneratorNode(RegulatableMESModel):
-    """Node representing a generator
-    """
+    """Node representing a generator"""
 
     def active_power(self):
         """
@@ -311,7 +356,7 @@ class GeneratorNode(RegulatableMESModel):
 
     def voltage(self):
         """
-        :return: voltage 
+        :return: voltage
         :rtype: [type]
         """
         return self._network.res_gen[VOLTAGE][self._id]
@@ -322,7 +367,7 @@ class GeneratorNode(RegulatableMESModel):
         :rtype: float
         """
         return self._network.res_gen[VOLTAGE_ANGLE][self._id]
-    
+
     def regulate(self, new_scaling):
         """Set the regulation factor.
 
@@ -353,16 +398,16 @@ class GeneratorNode(RegulatableMESModel):
         :rtype: float
         """
         return self._network.gen[ACTIVE_POWER][self._id]
-    
+
     def component_type(self):
         return "gen"
 
     def values_as_dict(self):
         return self._network.res_gen.iloc[self._id]
 
+
 class SinkNode(RegulatableMESModel):
-    """Node representing a sink
-    """
+    """Node representing a sink"""
 
     def mdot_kg_per_s(self):
         """
@@ -378,7 +423,7 @@ class SinkNode(RegulatableMESModel):
         :rtype: float
         """
         return self._network.sink[MDOT_KG_PER_S][self._id]
-    
+
     def regulate(self, new_scaling):
         """Set the regulation factor.
 
@@ -408,9 +453,9 @@ class SinkNode(RegulatableMESModel):
     def values_as_dict(self):
         return self._network.res_sink.iloc[self._id]
 
+
 class SourceNode(RegulatableMESModel):
-    """Node representing a source
-    """
+    """Node representing a source"""
 
     def mdot_kg_per_s(self):
         """
@@ -426,7 +471,7 @@ class SourceNode(RegulatableMESModel):
         :rtype: float
         """
         return self._network.source[MDOT_KG_PER_S][self._id]
-    
+
     def regulate(self, new_scaling):
         """Set the regulation factor.
 
@@ -456,9 +501,9 @@ class SourceNode(RegulatableMESModel):
     def values_as_dict(self):
         return self._network.res_source.iloc[self._id]
 
+
 class HeatExchangerNode(RegulatableMESModel):
-    """Node representing a heat exchanger
-    """
+    """Node representing a heat exchanger"""
 
     def mdot_kg_per_s(self):
         """
@@ -482,7 +527,7 @@ class HeatExchangerNode(RegulatableMESModel):
         :rtype: float
         """
         return self._network.heat_exchanger[QEXT_W][self._id]
-    
+
     def regulate(self, new_scaling):
         """Set the regulation factor.
 
@@ -510,13 +555,14 @@ class HeatExchangerNode(RegulatableMESModel):
         return "heat_exchanger"
 
     def values_as_dict(self):
-        return {**self._network.res_heat_exchanger.iloc[self._id], 
-                    'qext_w': self._network.heat_exchanger[QEXT_W][self._id]}
+        return {
+            **self._network.res_heat_exchanger.iloc[self._id],
+            "qext_w": self._network.heat_exchanger[QEXT_W][self._id],
+        }
 
 
 class ExtGasGrid(RegulatableMESModel):
-    """Node representing a ext grid in a gas network
-    """
+    """Node representing a ext grid in a gas network"""
 
     def regulate(self, new_scaling):
         """Set the regulation factor.
@@ -547,9 +593,9 @@ class ExtGasGrid(RegulatableMESModel):
     def values_as_dict(self):
         return self._network.res_ext_grid.iloc[self._id]
 
+
 class ExtPowerGrid(RegulatableMESModel):
-    """Node representing a ext grid in a power network
-    """
+    """Node representing a ext grid in a power network"""
 
     def regulate(self, new_scaling):
         """Set the regulation factor.
@@ -580,8 +626,8 @@ class ExtPowerGrid(RegulatableMESModel):
     def values_as_dict(self):
         return self._network.res_ext_grid.iloc[self._id]
 
-class EmptyBusNode(RegulatableMESModel):
 
+class EmptyBusNode(RegulatableMESModel):
     def regulate(self, _):
         pass
 
@@ -607,7 +653,6 @@ class EmptyBusNode(RegulatableMESModel):
 
 
 class EmptyJunctionNode(RegulatableMESModel):
-
     def regulate(self, _):
         pass
 
@@ -615,8 +660,8 @@ class EmptyJunctionNode(RegulatableMESModel):
         return 1
 
     def mdot_kg_per_s_capability(self):
-        return 0    
-    
+        return 0
+
     def name(self):
         """Return name of the ext grid
 
